function VI = VIcurveAnalysis(Vc, Iinj, t, files)

% Extracting start/end of stimulation
StartStep = find(min(Iinj), 1, 'first');
EndStep = find(min(Iinj), 1, 'last');

% Initializing variables
V = zeros(size(Vc, 1), 1);
I = nan(size(Vc, 1), 1);
V0 = zeros(size(Vc, 1), 1);
Vmin = zeros(size(Vc, 1), 1);
rebound = zeros(size(Vc, 1), 1);
for i = 1:size(Vc,1) % Loop over different recordings
    
    [~, info] = loadH5Trace(files{i});
    
    % Take the average from the last half of the stimulation, where the
    % neuron has stabilised
    V(i,:) = mean(Vc(i, StartStep + info.srate/2:EndStep));
    I(i,:) = mean(Iinj(i, StartStep + info.srate/2:EndStep));

    V0(i,:) = mean(Vc(1,1:StartStep-1));
    
    % Extracting the voltage sag for the most negative depolarization
    if I(i) == min(I, 'omitnan')
        [sag, sagInd] = min(Vc(i,StartStep:45000));
        sag = abs(sag - V(i));
    end
    
    Vmin(i,:) = min(Vc(i,:));
    rebound(i,:) = abs(max(Vc(i, EndStep:end)) - V0(i));
    
end

resting = mean(V0);

% Ih mediated voltage sag

timetosag = sagInd * info.dt * 1000;

if timetosag > 30
    voltageSag = max(sag);   
else  
    voltageSag = 0;   
end

% Rebound after step offset
reboundSag = max(rebound);

% Input resistance

f1 = fit(I,V,'poly1');
f2 = fit(I, Vmin, 'poly1');

coeff1 = coeffvalues(f1);
resistanceSteadyState = coeff1(1)*1000;

coeff2 = coeffvalues(f2);
resistancePeak = coeff2(1)*1000;

%% Plot figure

figure
hold on
set(gcf, 'color', 'white');

subplot(2,2,1)
plot(t, Iinj, 'k');
title('current step, pA');
xlabel('time, s'); ylim([-220 0]);
box off

subplot(2,2,2)
plot(t, Vc, 'k');
title('voltage, mV');
xlabel('time, s');
box off

subplot(2,2,[3 4])
plot(f1,I,V,'k.');
xlabel('current, pA'); ylabel('voltage, mV');
box off
legend off

text(0.9*min(I), 1.1*max(V), sprintf(' R = %g M\\Omega\n voltage sag amplitude = %g mV\n resting potential = %g mV', ...
    resistanceSteadyState, voltageSag, resting));

%% Creating data structure

VI.V = V;
VI.I = I;
VI.V0 = V0;
VI.resistanceSteadyState = resistanceSteadyState;
VI.resistancePeak = resistancePeak;
VI.voltageSag = voltageSag;
VI.TimeToSag = timetosag;
VI.resting = resting;
VI.reboundSag = reboundSag;

end
