function [fI, AP1, AP2, AP_averageSpike] = fIcurveAnalysisV2(Vc, Iinj, t)

% Extracting start/end of step stimulation
StartStep = find(Iinj == max(Iinj), 1, 'first');
EndStep = find(Iinj == max(Iinj), 1, 'last');

% Initializing variables
f = zeros(size(Vc, 1), 1);
I = zeros(size(Vc, 1), 1);
pks = cell(size(Vc, 1), 1);
locs = cell(size(Vc, 1), 1);
spikeTimes = cell(size(Vc, 1), 1);
allISI = cell(size(Vc, 1), 1);
allCV = zeros(size(Vc, 1), 1);

for i = 1:size(Vc,1) % Loop over different recordings
    
    stepduration = (EndStep - StartStep) * t(2);
    
    [pks{i}, locs{i}] = findpeaks(Vc(i,StartStep:EndStep), 'MinPeakHeight', -20, 'MinPeakWidth', 20); % Extracting AP
    
    f(i,:) = length(pks{i})/stepduration; % Firing frequency
    I(i,:) = max(Iinj(i,:)); % Value of step current
    spikeTimes{i} = locs{i} .* t(2);
    allISI{i} = spikeTimes{i}(2:end) - spikeTimes{i}(1:end-1);
    allCV(i,:) = std(allISI{i}) ./ mean(allISI{i});
end

MinPeakWidth = 20;
peakdetection = 0;

% Initializing variables
frange = 10:10:30;
idx102030 = zeros(size(frange, 2), 1);
ISI = cell(size(frange, 2), 1);
CV = zeros(size(frange, 2), 1);

while ~peakdetection
    
    fig1 = figure();
    set(gcf, 'color', 'white');
    
    for i = 1:length(frange)
        
        [~, idx102030(i)]= min(abs(f - frange(i)));
        
        [APpeaks, APlocs] = findpeaks(Vc(idx102030(i), StartStep:EndStep), 'MinPeakHeight', -10, 'MinPeakWidth', MinPeakWidth);
        
        spiketimes = APlocs .* t(2);
        
        ISI{i} = spiketimes(2:end) - spiketimes(1:end-1);
        CV(i) = std(ISI{i} .* 1000) ./ mean(ISI{i} .* 1000);
        
        subplot(2,3,i)
        hold on
        box off
        plot(Vc(idx102030(i),StartStep:EndStep));
        plot(APlocs, APpeaks, 'r*', 'markersize', 10);
        
        subplot(2,3,i+3)
        hold on
        box off
        plot(ISI{i, :}*1000);
        ylim([0 200]);
        
    end
    
    % If peak detection was not ok, this can be remedied by inputting 0 and
    % setting a new minimum peak width
    peakdetection = input('is action potential detection okay? [0/1] ');
    if peakdetection == 0
        MinPeakWidth = input('select another threshold for action potential detection: ');
    end
    
end

% Saving of the figure
pathtosave = [pwd '/fi/01'];
saveas(fig1, fullfile ([pathtosave '/'], 'SpikeTrains_ISI'), 'fig');


% Calculate AP parameters
[AP1, AP2, AP_averageSpike] = apAnalysisV2(Vc, Iinj, f, t, MinPeakWidth);

% Calculating AHP parameters
sAHP_idx = find(Vc(idx102030(2), :) == min(Vc(idx102030(2), :)), 1, 'last');
sAHP_peak = Vc(idx102030(2), sAHP_idx);
sAHP_amp = abs(sAHP_peak - AP_averageSpike.threshold);

TimeToAHP = (sAHP_idx - EndStep) * t(2) * 1000;

sAHP2_idx = EndStep + (30000 * 100 / 1000); % For sampling rate of 30 kHz
sAHP2_peak = Vc(idx102030(2), sAHP2_idx);
sAHP2_amp = abs(sAHP2_peak - AP_averageSpike.threshold);

% Calculating burst parameters
InitialBurstInterval = mean(ISI{2, 1}(1:2) .* 1000);
SD_InitialBurstInterval = std(ISI{2, 1}(1:2) .* 1000);

ISI1st = ISI{2, 1}(1) * 1000;

BurstingIndex = (ISI{2, 1}(1) * 1000) ./ (mean(ISI{2, 1} * 1000));

AdaptationCoeff = (ISI{2, 1}(end) * 1000) / (ISI{2, 1}(1) * 1000);

ModalityBurst = size(ISI{2, 1}(ISI{2,1} * 1000 < 30),2) / size(ISI{2, 1}(ISI{2,1} * 1000 > 30),2);

averageISI = ((stepduration / f(idx102030(2))) + (5/100 * stepduration / f(idx102030(2)))) * 1000;

PauseIndex = size(ISI{2, 1}(ISI{2,1} * 1000 > averageISI),2) / size(ISI{2, 1}(ISI{2,1} * 1000 < averageISI),2);

PauseRatio = (sum(ISI{2, 1}(ISI{2,1} * 1000 > averageISI)) * 1000) / (sum(ISI{2, 1}(ISI{2,1} * 1000 < averageISI)) * 1000);

VariabilityVariance = var(ISI{2, 1} .* 1000) / mean(ISI{2, 1} .* 1000);

StutteringIndex = size(ISI{2, 1}(ISI{2,1} * 1000 > 80),2) / size(ISI{2, 1}(ISI{2,1} * 1000 < 80),2);


% Linear fit of ISI at 10 and 20 Hz

ISI10 = ISI{1};
CV10 = CV(1);

ISI20 = ISI{2};
CV20 = CV(2);

xfit10 = 1:1:length(ISI10);
yfit10 = ISI10 * 1000;

[fit10, gof10] = fit(xfit10', yfit10', 'poly1');

coeff10 = coeffvalues(fit10);
slopefit10 = coeff10(1);

xfit20 = 1:1:length(ISI20);
yfit20 = ISI20 * 1000;

[fit20, gof20] = fit(xfit20', yfit20', 'poly1');

coeff20 = coeffvalues(fit20);
slopefit20 = coeff20(1);

% Fitting I50
ft=fittype('a/(1+exp(-b*(x-c)))', 'independent', 'x', 'dependent', 'y');
opts = fitoptions('Method', 'NonlinearLeastSquares');
opts.Display = 'Off';
opts.StartPoint = [max(f)+10, 0,  I(f == min(f(f>0)))];
[fitresult, gof] = fit(I, f, ft, opts);
coeff = coeffvalues(fitresult);
xfit = 0:0.01:max(I);
fitY = coeff(1)./(1+exp(-coeff(2)*(xfit-coeff(3))));

fitY1 = diff(fitY)/0.01;
gain = max(fitY1);
I50 = coeff(3);

% Plotting the data

figure(2)
hold on
set(gcf, 'color', 'white');

subplot(2,2,1)
plot(t, Vc(idx102030(1),:));
xlabel('time, s');
ylabel('membrane potential, mV');
title('10 Hz');
box off

subplot(2,2,2)
plot(t, Vc(idx102030(2),:));
xlabel('time, s');
ylabel('membrane potential, mV');
title('20 Hz');
box off

subplot(2,2,3)
hold on
plot(I,f, 'r.', 'MarkerSize', 15);
plot(xfit, fitY, 'k');
legend off
xlabel('current, pA');
ylabel('firing frequency, Hz');
title('fI curve');
box off

subplot(2,2,4)
plot(1:length(ISI20), ISI20 .* 1000, '.-');
ylim([0 200]);
xlabel('spike number'); ylabel('ISI, ms');
title('ISI');
box off

firingtype = input('score firing type: [1]cAC [2]cNAC [3]bNAC [4]cSTUT [5]cIR: '); % Getting the etype

% Storing the data in a structure

fI.f = f;
fI.I = I;
fI.CV = CV;
fI.gain = gain;
fI.I50 = I50;
fI.GoodnessOfFit = gof;
fI.Average_InitialBurstInterval = InitialBurstInterval;
fI.SD_AverageInitialBurstInterval = SD_InitialBurstInterval;
fI.ISI1st = ISI1st;
fI.BurstingIndex = BurstingIndex;
fI.AdaptiationCoefficient = AdaptationCoeff;
fI.ModalityBurst = ModalityBurst;
fI.PauseIndex = PauseIndex;
fI.PauseRatio = PauseRatio;
fI.VariabilityVariance = VariabilityVariance;
fI.StutteringIndex = StutteringIndex;

fI.sAHP1_amplitude = sAHP_amp;
fI.sAHP2_amplitude = sAHP2_amp;
fI.TimeToMaximalAHP = TimeToAHP;

fI.eType = firingtype;

fI.CV10 = CV10;
fI.ISI10 = ISI10 .* 1000;
fI.CV20 = CV20;
fI.ISI20 = ISI20 .* 1000;
fI.allISI = allISI;
fI.allCV = allCV;

fI.fit10Hz = fit10;
fI.slopefit10 = slopefit10;
fI.RMSE10 = gof10.rmse;
fI.fit20Hz = fit20;
fI.slopefit20 = slopefit20;
fI.RMSE20 = gof20.rmse;

% Saving the figure
saveas(figure(2), fullfile ([pathtosave '/'], 'fI_curve'), 'fig');

end
