function ramp = rampAnalysis(Vc, Iinj, t, files)

% Initializing variables
thresInd = zeros(length(files),1);
thresholds = zeros(length(files),1);
rheobases = zeros(length(files),1);

for i = 1:size(Vc,1) % Loop over different recordings
    
    [entities, info] = loadH5Trace(files{i});
    
    [~, LOCS] = findpeaks(Vc(i,:), 'MinPeakHeight', -20, 'MinPeakWidth', 15); % Extracting the AP
    
    SpikeStart = LOCS(1,1) - 5*info.srate/1000;
    traceDiff = diff(Vc(i,1:end)) ./ (info.dt*1000);
    
    % Finding the threshold for spike generation
    thresInd(i) = find(traceDiff(SpikeStart:end) > 20, 1);
    thresInd(i) = thresInd(i) + SpikeStart-1;
    thresholds(i) = Vc(i,thresInd(i));
    
    rheobases(i) = Iinj(i, thresInd(i)); % Extracting the rheobase from the thresholds
    
    AHPpeak(i) = min(entities(1).data(LOCS(1):LOCS(2)));
    AHPamp(i) = abs(AHPpeak(i) - thresholds(i));
    
end

Threshold = mean(thresholds);
Rheobase = mean(rheobases);
fAHP = mean(AHPamp);

% Plotting the data
figure(5)
hold on
set(gcf, 'color', 'white');
box off

subplot(6, 1, 1:4)
plot(t(2*info.srate:end)-2, Vc(1,2*info.srate:end), 'k');
box off
axis tight
ylabel('mV');
ax =  gca();
ax.XAxis.Visible = 'off';

subplot(6, 1, 5:6)
plot(t(1,2*info.srate:end)-2, Iinj(1,2*info.srate:end), 'r');
xlabel('time, s');
ylabel('pA');
axis tight
box off
text(2, 180, sprintf(' voltage threshold = %g mV\n rheobase current = %g pA', Threshold, Rheobase), ...
    'FontSize', 10);

% Storing data in structure
ramp.threshold = Threshold;
ramp.rheobase = Rheobase;
ramp.fAHP = fAHP;

% Saving the figure
pathtosave = [pwd '/ramp/01'];
saveas(gcf, fullfile ([pathtosave '/'], 'ramp'), 'fig');

end