function tau = tauAnalysis(Vc, t, files)

figure(4)
hold on
box off
set(gcf, 'color', 'white');

for i = 1:size(Vc,1)
    
    [~, info] = loadH5Trace(files{i});
    plot(t(13500:end), Vc(i,13500:end), 'Color', [.6,.6,.6]);
    
end

averagetrace = mean(Vc); % Calculate the averate trace

[MIN, MINind] = min(averagetrace);
timevec = 0:info.dt:t(end)-t(MINind);

% Fitting double exponential to decay to rest potential
ft=fittype('a*exp(-b*x)+c*exp(-d*x)+e', 'independent', 'x', 'dependent', 'y');
opts = fitoptions('Method', 'NonlinearLeastSquares');
opts.Display = 'Off'; % don't show display with fitting options
opts.StartPoint = [averagetrace(end)-MIN , 10 , averagetrace(end)-MIN , 50 , averagetrace(end)]; % Using intelligent starting points to optimize the fitting routine
opts.Lower = [-Inf, 0, -Inf, 0, -Inf];
[fitresult, gof] = fit(timevec', averagetrace(MINind:end)', ft, opts);
coeff = coeffvalues(fitresult);
fitY = coeff(1)*exp(-coeff(2)*timevec)+coeff(3)*exp(-coeff(4)*timevec)+coeff(5);

tau1 = (1/coeff(2))*1000;
tau2 = (1/coeff(4))*1000;

plot(t(13500:end), averagetrace(13500:end), 'k', 'LineWidth', 3);
plot(t(MINind:end), fitY, 'r*', 'MarkerSize', 3);

text(0.6, 0.9* min(averagetrace), sprintf(' double exponential fit:\n tau1 = %g ms, tau2 = %g ms', ...
    tau1, tau2), 'FontSize', 12);

ylim([-Inf -40]);
axis tight

% Creating data struct to keep relavent results of fitting
tau.tau1 = tau1;
tau.tau2 = tau2;
tau.GoodnessOfFit = gof;

pathtosave = [pwd '/tau/01'];
saveas(gcf, fullfile ([pathtosave '/'], 'tau'), 'fig');

end